@@ -32,15 +32,20 @@ async def test_keywords():
         ["127.0.0.1"] * 3,
         connect_options=dict(known_hosts=None),
         asynchronous=True,
-        worker_options={"nthreads": 2, "memory_limit": "2 GiB", "death_timeout": "5s"},
-        scheduler_options={"idle_timeout": "5s", "port": 0},
+        worker_options={
+            "nprocs": 2,  # nprocs checks custom arguments with cli_keywords
+            "nthreads": 2,
+            "memory_limit": "2 GiB",
+            "death_timeout": "5s",
+        },
+        scheduler_options={"idle_timeout": "10s", "port": 0},
     ) as cluster:
         async with Client(cluster, asynchronous=True) as client:
             assert (
                 await client.run_on_scheduler(
                     lambda dask_scheduler: dask_scheduler.idle_timeout
                 )
-            ) == 5
+            ) == 10
             d = client.scheduler_info()["workers"]
             assert all(v["nthreads"] == 2 for v in d.values())
 
@@ -58,6 +63,24 @@ def test_defer_to_old(loop):
             assert isinstance(c, OldSSHCluster)
 
 
+@pytest.mark.avoid_travis
+def test_old_ssh_wih_local_dir(loop):
+    with pytest.warns(Warning):
+        from distributed.deploy.old_ssh import SSHCluster as OldSSHCluster
+
+        with OldSSHCluster(
+            scheduler_addr="127.0.0.1",
+            scheduler_port=7437,
+            worker_addrs=["127.0.0.1", "127.0.0.1"],
+            local_directory="/tmp",
+        ) as c:
+            assert len(c.workers) == 2
+            with Client(c) as client:
+                result = client.submit(lambda x: x + 1, 10)
+                result = result.result()
+                assert result == 11
+
+
 @pytest.mark.asyncio
 async def test_config_inherited_by_subprocess(loop):
     def f(x):
@@ -74,3 +97,21 @@ async def test_config_inherited_by_subprocess(loop):
             async with Client(cluster, asynchronous=True) as client:
                 result = await client.submit(f, 1)
                 assert result == 101
+
+
+@pytest.mark.asyncio
+async def test_unimplemented_options():
+    with pytest.raises(Exception):
+        async with SSHCluster(
+            ["127.0.0.1"] * 3,
+            connect_kwargs=dict(known_hosts=None),
+            asynchronous=True,
+            worker_kwargs={
+                "nthreads": 2,
+                "memory_limit": "2 GiB",
+                "death_timeout": "5s",
+                "unimplemented_option": 2,
+            },
+            scheduler_kwargs={"idle_timeout": "5s", "port": 0},
+        ) as cluster:
+            assert cluster
