@@ -1,3 +1,4 @@
+from contextlib import suppress
 import logging
 import html
 from timeit import default_timer
@@ -12,7 +13,7 @@ from .progress import format_time, Progress, MultiProgress
 from ..core import connect, coerce_to_address, CommClosedError
 from ..client import default_client, futures_of
 from ..protocol.pickle import dumps
-from ..utils import ignoring, key_split, is_kernel, LoopRunner, parse_timedelta
+from ..utils import key_split, is_kernel, LoopRunner, parse_timedelta
 
 
 logger = logging.getLogger(__name__)
@@ -98,7 +99,7 @@ class ProgressBar:
         pass
 
     def __del__(self):
-        with ignoring(AttributeError):
+        with suppress(AttributeError):
             self.comm.abort()
 
 
@@ -130,7 +131,7 @@ class TextProgressBar(ProgressBar):
         msg = "\r[{0:<{1}}] | {2}% Completed | {3}".format(
             bar, self.width, percent, elapsed
         )
-        with ignoring(ValueError):
+        with suppress(ValueError):
             sys.stdout.write(msg)
             sys.stdout.flush()
 
@@ -286,7 +287,7 @@ class MultiProgressBar:
         pass
 
     def __del__(self):
-        with ignoring(AttributeError):
+        with suppress(AttributeError):
             self.comm.abort()
 
 
