@@ -1,5 +1,6 @@
 import asyncio
 import random
+from datetime import timedelta
 from time import sleep, monotonic
 import logging
 
@@ -98,7 +99,7 @@ async def test_timeout(c, s, a, b):
 
     start = monotonic()
     with pytest.raises(TimeoutError):
-        await v.get(timeout=0.2)
+        await v.get(timeout="200ms")
     stop = monotonic()
 
     if WINDOWS:  # timing is weird with asyncio and Windows
@@ -107,7 +108,7 @@ async def test_timeout(c, s, a, b):
         assert 0.2 < stop - start < 2.0
 
     with pytest.raises(TimeoutError):
-        await v.get(timeout=0.01)
+        await v.get(timeout=timedelta(milliseconds=10))
 
 
 def test_timeout_sync(client):
