@@ -2,7 +2,6 @@
 
 from __future__ import print_function, division, absolute_import
 
-from collections import defaultdict
 import platform
 import struct
 import os
@@ -32,6 +31,14 @@ scheduler_relevant_packages = set(pkg for pkg, _ in required_packages) | set(
 )
 
 
+# notes to be displayed for mismatch packages
+notes_mismatch_package = {
+    "msgpack": "Variation is ok, as long as everything is above 0.6",
+    "lz4": "Variation is ok, but missing libraries are not",
+    "python": "Variation is sometimes ok, sometimes not. It depends on your workloads",
+}
+
+
 def get_versions(packages=None):
     """
     Return basic information on our software installation, and our installed versions of packages.
@@ -51,30 +58,30 @@ def get_versions(packages=None):
 
 def get_system_info():
     (sysname, nodename, release, version, machine, processor) = platform.uname()
-    host = [
-        ("python", "%d.%d.%d.%s.%s" % sys.version_info[:]),
-        ("python-bits", struct.calcsize("P") * 8),
-        ("OS", "%s" % sysname),
-        ("OS-release", "%s" % release),
-        ("machine", "%s" % machine),
-        ("processor", "%s" % processor),
-        ("byteorder", "%s" % sys.byteorder),
-        ("LC_ALL", "%s" % os.environ.get("LC_ALL", "None")),
-        ("LANG", "%s" % os.environ.get("LANG", "None")),
-    ]
+    host = {
+        "python": "%d.%d.%d.%s.%s" % sys.version_info[:],
+        "python-bits": struct.calcsize("P") * 8,
+        "OS": "%s" % sysname,
+        "OS-release": "%s" % release,
+        "machine": "%s" % machine,
+        "processor": "%s" % processor,
+        "byteorder": "%s" % sys.byteorder,
+        "LC_ALL": "%s" % os.environ.get("LC_ALL", "None"),
+        "LANG": "%s" % os.environ.get("LANG", "None"),
+    }
 
     return host
 
 
 def version_of_package(pkg):
     """ Try a variety of common ways to get the version of a package """
-    from .utils import ignoring
+    from contextlib import suppress
 
-    with ignoring(AttributeError):
+    with suppress(AttributeError):
         return pkg.__version__
-    with ignoring(AttributeError):
+    with suppress(AttributeError):
         return str(pkg.version)
-    with ignoring(AttributeError):
+    with suppress(AttributeError):
         return ".".join(map(str, pkg.version_info))
     return None
 
@@ -82,7 +89,7 @@ def version_of_package(pkg):
 def get_package_info(pkgs):
     """ get package versions for the passed required & optional packages """
 
-    pversions = []
+    pversions = [("python", ".".join(map(str, sys.version_info)))]
     for pkg in pkgs:
         if isinstance(pkg, (tuple, list)):
             modname, ver_f = pkg
@@ -106,38 +113,56 @@ def get_package_info(pkgs):
 def error_message(scheduler, workers, client, client_name="client"):
     from .utils import asciitable
 
-    nodes = {**{client_name: client}, **{"scheduler": scheduler}, **workers}
+    client = client.get("packages") if client else "UNKNOWN"
+    scheduler = scheduler.get("packages") if scheduler else "UNKNOWN"
+    workers = {k: v.get("packages") if v else "UNKNOWN" for k, v in workers.items()}
 
-    # Hold all versions, e.g. versions["scheduler"]["distributed"] = 2.9.3
-    node_packages = defaultdict(dict)
-
-    # Collect all package versions
     packages = set()
-
-    for node, info in nodes.items():
-        if info is None or not (isinstance(info, dict)) or "packages" not in info:
-            node_packages[node] = defaultdict(lambda: "UNKNOWN")
-        else:
-            node_packages[node] = defaultdict(lambda: "MISSING")
-            for pkg, version in info["packages"].items():
-                node_packages[node][pkg] = version
-                packages.add(pkg)
+    packages.update(client)
+    packages.update(scheduler)
+    for worker in workers:
+        packages.update(workers.get(worker))
 
     errs = []
+    notes = []
     for pkg in sorted(packages):
-        versions = set(
-            node_packages[node][pkg]
-            for node in nodes
-            if node != "scheduler" or pkg in scheduler_relevant_packages
+        versions = set()
+        scheduler_version = (
+            scheduler.get(pkg, "MISSING") if isinstance(scheduler, dict) else scheduler
         )
+        if pkg in scheduler_relevant_packages:
+            versions.add(scheduler_version)
+
+        client_version = (
+            client.get(pkg, "MISSING") if isinstance(client, dict) else client
+        )
+        versions.add(client_version)
+
+        worker_versions = set(
+            workers[w].get(pkg, "MISSING")
+            if isinstance(workers[w], dict)
+            else workers[w]
+            for w in workers
+        )
+        versions |= worker_versions
+
         if len(versions) <= 1:
             continue
-        rows = [
-            (node_name, node_packages[node_name][pkg]) for node_name in nodes.keys()
-        ]
-        errs.append("%s\n%s" % (pkg, asciitable(["", "version"], rows)))
+        if len(worker_versions) == 1:
+            worker_versions = list(worker_versions)[0]
+        elif len(worker_versions) == 0:
+            worker_versions = None
+
+        errs.append((pkg, client_version, scheduler_version, worker_versions))
+        if pkg in notes_mismatch_package.keys():
+            notes.append(f"-  {pkg}: {notes_mismatch_package[pkg]}")
+
     if errs:
-        return "Mismatched versions found\n" "\n" "%s" % ("\n\n".join(errs))
+        err_table = asciitable(["Package", client_name, "scheduler", "workers"], errs)
+        err_msg = f"Mismatched versions found\n\n{err_table}"
+        if notes:
+            err_msg += "\nNotes: \n{}".format("\n".join(notes))
+        return err_msg
     else:
         return ""
 
